@@ -71,6 +71,8 @@ public:
     explicit MainApplication(int &argc, char** argv);
     ~MainApplication();
 
+    void setChromiumFlags();
+
     bool isClosing() const;
     bool isPrivate() const;
     bool isPortable() const;
@@ -80,7 +82,8 @@ public:
     QList<BrowserWindow*> windows() const;
 
     BrowserWindow* getWindow() const;
-    BrowserWindow* createWindow(Qz::BrowserWindowType type, const QUrl &startUrl = QUrl());
+    BrowserWindow* createWindow(Qz::BrowserWindowType type, const QUrl &startUrl);
+    BrowserWindow* createWindow(Qz::BrowserWindowType type, const QList<QUrl> &startUrls = {});
 
     AfterLaunch afterLaunch() const;
 
@@ -167,6 +170,7 @@ private:
     void checkOptimizeDatabase();
 
     void registerAllowedSchemes();
+    void initNetworkInformation();
 
     bool m_isPrivate;
     bool m_isPortable;
