@@ -177,7 +177,11 @@ void MainMenu::savePageAs()
 
 void MainMenu::sendLink()
 {
-    const QUrl mailUrl = QUrl::fromEncoded("mailto:%20?body=" + QUrl::toPercentEncoding(QString::fromUtf8(m_window->weView()->url().toEncoded())) + "&subject=" + QUrl::toPercentEncoding(m_window->weView()->title()));
+    const QUrl mailUrl = QUrl::fromEncoded(QByteArray(
+        "mailto:%20?body=" +
+        QUrl::toPercentEncoding(
+            QString::fromUtf8(m_window->weView()->url().toEncoded())) +
+        "&subject=" + QUrl::toPercentEncoding(m_window->weView()->title())));
     QDesktopServices::openUrl(mailUrl);
 }
 
