@@ -40,11 +40,7 @@ LocationCompleterRefreshJob::LocationCompleterRefreshJob(const QString &searchSt
     m_watcher = new QFutureWatcher<void>(this);
     connect(m_watcher, &QFutureWatcherBase::finished, this, &LocationCompleterRefreshJob::slotFinished);
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    QFuture<void> future = QtConcurrent::run(this, &LocationCompleterRefreshJob::runJob);
-#else
     QFuture<void> future = QtConcurrent::run(&LocationCompleterRefreshJob::runJob, this);
-#endif
     m_watcher->setFuture(future);
 }
 
@@ -104,7 +100,7 @@ void LocationCompleterRefreshJob::runJob()
     }
 
     // Load all icons into QImage
-    for (QStandardItem* item : qAsConst(m_items)) {
+    for (QStandardItem* item : std::as_const(m_items)) {
         if (m_jobCancelled) {
             return;
         }
@@ -166,7 +162,7 @@ void LocationCompleterRefreshJob::completeFromHistory()
             }
 
             auto* item = new QStandardItem();
-            item->setText(bookmark->url().toEncoded());
+            item->setText(QString::fromUtf8(bookmark->url().toEncoded()));
             item->setData(-1, LocationCompleterModel::IdRole);
             item->setData(bookmark->title(), LocationCompleterModel::TitleRole);
             item->setData(bookmark->url(), LocationCompleterModel::UrlRole);
@@ -197,7 +193,7 @@ void LocationCompleterRefreshJob::completeFromHistory()
             }
 
             auto* item = new QStandardItem();
-            item->setText(url.toEncoded());
+            item->setText(QString::fromUtf8(url.toEncoded()));
             item->setData(query.value(0), LocationCompleterModel::IdRole);
             item->setData(query.value(2), LocationCompleterModel::TitleRole);
             item->setData(url, LocationCompleterModel::UrlRole);
@@ -219,7 +215,7 @@ void LocationCompleterRefreshJob::completeMostVisited()
         auto* item = new QStandardItem();
         const QUrl url = query.value(1).toUrl();
 
-        item->setText(url.toEncoded());
+        item->setText(QString::fromUtf8(url.toEncoded()));
         item->setData(query.value(0), LocationCompleterModel::IdRole);
         item->setData(query.value(2), LocationCompleterModel::TitleRole);
         item->setData(url, LocationCompleterModel::UrlRole);
