@@ -34,9 +34,9 @@ class FALKON_EXPORT SslErrorDialog : public QDialog
     Q_OBJECT
 
 public:
-    enum Result { Yes, No, OnlyForThisSession };
+    enum Result { Yes, No, OnlyForThisSession, NoForThisSession };
 
-    explicit SslErrorDialog(QWidget* parent = 0);
+    explicit SslErrorDialog(QWidget* parent = nullptr);
     ~SslErrorDialog();
 
     void setText(const QString &text);
