@@ -63,6 +63,7 @@
 #include <QWebEngineSettings>
 #include <QLibraryInfo>
 #include <QtWebEngineWidgetsVersion>
+#include <QtGuiVersion>
 
 static QString createLanguageItem(const QString &lang)
 {
@@ -72,7 +73,7 @@ static QString createLanguageItem(const QString &lang)
         return lang;
     }
 
-    const QString country = QLocale::countryToString(locale.country());
+    const QString territory = QLocale::territoryToString(locale.territory());
     const QString language = QLocale::languageToString(locale.language());
 
     if (lang == QLatin1String("es_ES")) {
@@ -93,7 +94,7 @@ static QString createLanguageItem(const QString &lang)
     if (lang == QLatin1String("sr@ijekavianlatin")) {
         return QString::fromUtf8("srpski ijekavski");
     }
-    return QStringLiteral("%1, %2 (%3)").arg(language, country, lang);
+    return QStringLiteral("%1, %2 (%3)").arg(language, territory, lang);
 }
 
 Preferences::Preferences(BrowserWindow* window)
@@ -237,6 +238,7 @@ Preferences::Preferences(BrowserWindow* window)
     ui->openNewTabAfterActive->setChecked(settings.value(QSL("newTabAfterActive"), true).toBool());
     ui->openNewEmptyTabAfterActive->setChecked(settings.value(QSL("newEmptyTabAfterActive"), false).toBool());
     ui->openPopupsInTabs->setChecked(settings.value(QSL("OpenPopupsInTabs"), false).toBool());
+    ui->blockAutomaticPopups->setChecked(settings.value(QSL("BlockAutomaticPopups"), false).toBool());
     ui->alwaysSwitchTabsWithWheel->setChecked(settings.value(QSL("AlwaysSwitchTabsWithWheel"), false).toBool());
     ui->switchToNewTabs->setChecked(settings.value(QSL("OpenNewTabsSelected"), false).toBool());
     ui->dontCloseOnLastTab->setChecked(settings.value(QSL("dontCloseWithOneTab"), false).toBool());
@@ -287,7 +289,6 @@ Preferences::Preferences(BrowserWindow* window)
     ui->spatialNavigation->setChecked(settings.value(QSL("SpatialNavigation"), false).toBool());
     ui->animateScrolling->setChecked(settings.value(QSL("AnimateScrolling"), true).toBool());
     ui->wheelScroll->setValue(settings.value(QSL("wheelScrollLines"), qApp->wheelScrollLines()).toInt());
-    ui->xssAuditing->setChecked(settings.value(QSL("XSSAuditing"), false).toBool());
     ui->printEBackground->setChecked(settings.value(QSL("PrintElementBackground"), true).toBool());
     ui->useNativeScrollbars->setChecked(settings.value(QSL("UseNativeScrollbars"), false).toBool());
     ui->disableVideoAutoPlay->setChecked(settings.value(QSL("DisableVideoAutoPlay"), false).toBool());
@@ -308,6 +309,19 @@ Preferences::Preferences(BrowserWindow* window)
     ui->forceDarkMode->hide();
 #endif
 
+    int prefferColorSchemeSetting = settings.value(QSL("prefferColorScheme"), Qz::ColorScheme_Auto).toInt();
+#if QTGUI_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+    ui->prefferColorScheme->addItem(tr("Auto"), Qz::ColorScheme_Auto);
+#endif
+    ui->prefferColorScheme->addItem(tr("Light"), Qz::ColorScheme_Light);
+    ui->prefferColorScheme->addItem(tr("Dark"), Qz::ColorScheme_Dark);
+#if QTGUI_VERSION < QT_VERSION_CHECK(6, 5, 0)
+    if (prefferColorSchemeSetting > 0) {
+        prefferColorSchemeSetting--;
+    }
+#endif
+    ui->prefferColorScheme->setCurrentIndex(prefferColorSchemeSetting);
+
     const auto levels = WebView::zoomLevels();
     for (int level : levels) {
         ui->defaultZoomLevel->addItem(tr("%1%").arg(QString::number(level)));
@@ -943,6 +957,7 @@ void Preferences::saveSettings()
     settings.setValue(QSL("newTabAfterActive"), ui->openNewTabAfterActive->isChecked());
     settings.setValue(QSL("newEmptyTabAfterActive"), ui->openNewEmptyTabAfterActive->isChecked());
     settings.setValue(QSL("OpenPopupsInTabs"), ui->openPopupsInTabs->isChecked());
+    settings.setValue(QSL("BlockAutomaticPopups"), ui->blockAutomaticPopups->isChecked());
     settings.setValue(QSL("AlwaysSwitchTabsWithWheel"), ui->alwaysSwitchTabsWithWheel->isChecked());
     settings.setValue(QSL("OpenNewTabsSelected"), ui->switchToNewTabs->isChecked());
     settings.setValue(QSL("dontCloseWithOneTab"), ui->dontCloseOnLastTab->isChecked());
@@ -1000,7 +1015,6 @@ void Preferences::saveSettings()
     settings.setValue(QSL("CheckUpdates"), ui->checkUpdates->isChecked());
     settings.setValue(QSL("LoadTabsOnActivation"), ui->dontLoadTabsUntilSelected->isChecked());
     settings.setValue(QSL("DefaultZoomLevel"), ui->defaultZoomLevel->currentIndex());
-    settings.setValue(QSL("XSSAuditing"), ui->xssAuditing->isChecked());
     settings.setValue(QSL("PrintElementBackground"), ui->printEBackground->isChecked());
     settings.setValue(QSL("closeAppWithCtrlQ"), ui->closeAppWithCtrlQ->isChecked());
     settings.setValue(QSL("UseNativeScrollbars"), ui->useNativeScrollbars->isChecked());
@@ -1016,6 +1030,7 @@ void Preferences::saveSettings()
 #if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(6, 7, 0)
     settings.setValue(QSL("forceDarkMode"), ui->forceDarkMode->isChecked());
 #endif
+    settings.setValue(QSL("prefferColorScheme"), ui->prefferColorScheme->currentData().toInt());
 #ifdef Q_OS_WIN
     settings.setValue(QSL("CheckDefaultBrowser"), ui->checkDefaultBrowser->isChecked());
 #endif
