@@ -43,6 +43,9 @@ public:
 
     void wheelEvent(QWheelEvent* event) override;
 
+    void setIsRestoring(bool restoring);
+    bool isRestoring();
+
 Q_SIGNALS:
     void moveAddTabButton(int posX);
 
@@ -90,6 +93,8 @@ private:
 
     bool m_forceHidden;
     QPointer<WebTab> m_lastTab;
+
+    bool m_isRestoring = false;
 };
 
 #endif // TABBAR_H
